MBPushMessage class

A push message

Constructors

MBPushMessage({required String id, required String title, required String body, int? badge, String? sound, String? launchImage, Map<String, dynamic>? userInfo, required bool sent})
Initializes a new push message with the data given. @param id The id of the push message. @param title The title of the push message. @param body The body of the push message. @param badge The push notification badge value. @param sound The push notification custom sound. @param launchImage The push notification launch image. @param userInfo Additional data for push notifications. @param sent If the push notification was sent or not by the server.
MBPushMessage.fromDictionary(Map<String, dynamic> dictionary)
Initializes a push message from the dictionary returned from the APIs. @param dictionary The dictionary returned from the APIs.
factory

Properties

badge → int?
The push notification badge value.
final
body → String
The body of the push message.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The id of the push message.
final
launchImage → String?
The push notification launch image.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sent → bool
If the push notification was sent or not by the server.
final
sound → String?
The push notification custom sound.
final
title → String
The title of the push message.
final
userInfo → Map<String, dynamic>?
Additional data for push notifications.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited